@@ -13,6 +13,7 @@ pub use std::rc::Rc;
 pub use sharedptr::Arc::SharedPtr;
 #[cfg(feature ="Arc")]
 pub use std::sync::Arc;
+use std::fmt::Debug;
 
 /// 用于给类型返回TypeId
 pub trait ISerdeTypeId{
@@ -25,20 +26,27 @@ pub trait ISerdeTypeId{
 
 /// 序列化基本trait
 #[cfg(not(feature ="Arc"))]
-pub trait ISerde:ISerdeTypeId{
+pub trait ISerde:ISerdeTypeId+Debug{
     /// 写入当前对象 到 BytesMut
     fn write_to(&self,om:&ObjectManager,data:&mut Data)->Result<()>;
     /// 从Bytes 装载当前对象
     fn read_from(&mut self,om:&ObjectManager,data:&mut DataReader)->Result<()>;
+    fn debug(&self)->String{
+        format!("{:?}",self)
+    }
 }
 
 /// 序列化基本trait
 #[cfg(feature ="Arc")]
-pub trait ISerde:ISerdeTypeId+Send+Sync{
+pub trait ISerde:ISerdeTypeId+Debug+Send+Sync{
     /// 写入当前对象 到 BytesMut
     fn write_to(&self,om:&ObjectManager,data:&mut Data)->Result<()>;
     /// 从Bytes 装载当前对象
     fn read_from(&mut self,om:&ObjectManager,data:&mut DataReader)->Result<()>;
+
+    fn debug(&self)->String{
+        format!("{:?}",self)
+    }
 }
 
 /// 常规结构类型序列化反序列化接口
@@ -55,7 +63,8 @@ pub type CreateFn=fn() -> SharedPtr<dyn ISerde>;
 
 /// 用于存储类型和TypeId的映射 实现根据Typeid 创建对象
 pub struct TypeClass<const LEN:usize>{
-    register_table:UnsafeCell<[Option<CreateFn>;LEN]>
+   pub(crate) register_table:UnsafeCell<[Option<CreateFn>;LEN]>,
+   pub(crate) register_name:UnsafeCell<Vec<(u16,&'static str)>>
 }
 
 unsafe impl<const LEN:usize> Send for TypeClass<LEN>{}
@@ -64,14 +73,16 @@ unsafe impl<const LEN:usize> Sync for TypeClass<LEN>{}
 impl<const LEN:usize> TypeClass<LEN>{
     pub const fn new()->Self {
         TypeClass {
-            register_table:UnsafeCell::new([None;LEN])
+            register_table:UnsafeCell::new([None;LEN]),
+            register_name:UnsafeCell::new(Vec::new())
         }
     }
 
     /// 注册TypeId
-    pub fn register(&self,typeid:u16,cfn:CreateFn){
+    pub fn register(&self,typeid:u16,name:&'static str,cfn:CreateFn){
         unsafe {
-            (*self.register_table.get())[typeid as usize] =Some(cfn)
+            (*self.register_table.get())[typeid as usize] = Some(cfn);
+            (*self.register_name.get()).push((typeid,name));
         }
     }
 
