@@ -2,7 +2,7 @@
 use anyhow::*;
 use xxlib::*;
 use xxlib_builder::*;
-
+use sharedptr::unsafe_def::IGetMutUnchecked;
 
 #[build_enum(i32)]
 pub enum Flags{
@@ -60,7 +60,7 @@ pub fn test()->Result<()>{
 
     let foo2_ptr=SharedPtr::new(foo2);
     unsafe {
-        foo2_ptr.base.get_mut_ref().child = foo2_ptr.weak().ok_or_else(|| anyhow::anyhow!("is none"))?;
+        foo2_ptr.base.get_mut_unchecked().child = foo2_ptr.weak().ok_or_else(|| anyhow::anyhow!("is none"))?;
     }
 
     let mut data=Data::new();
