@@ -1,5 +1,6 @@
 use xxlib::*;
 use anyhow::*;
+use sharedptr::unsafe_def::IGetMutUnchecked;
 
 #[derive(Default,Debug,Clone)]
 struct Foo{
@@ -89,7 +90,7 @@ pub fn test()->Result<()>{
 
     let foo2_ptr=SharedPtr::new(foo2);
     unsafe {
-        foo2_ptr.base.get_mut_ref().child = foo2_ptr.weak().ok_or_else(|| anyhow!("is none"))?;
+        foo2_ptr.base.get_mut_unchecked().child = foo2_ptr.weak().ok_or_else(|| anyhow!("is none"))?;
     }
 
     let mut data=Data::new();
