@@ -29,7 +29,7 @@ pub mod test {
 
 use xxlib::*;
 use test::*;
-
+use sharedptr::unsafe_def::IGetMutUnchecked;
 
 #[test]
 pub fn test()->anyhow::Result<()>{
@@ -45,7 +45,7 @@ pub fn test()->anyhow::Result<()>{
 
     let foo2_ptr=SharedPtr::new(foo2);
     unsafe {
-        foo2_ptr.base.get_mut_ref().child = foo2_ptr.weak().ok_or_else(|| anyhow::anyhow!("is none"))?;
+        foo2_ptr.base.get_mut_unchecked().child = foo2_ptr.weak().ok_or_else(|| anyhow::anyhow!("is none"))?;
     }
 
     let mut data=Data::new();
